cfbd_coaches: *CFBD Coaches Endpoint Overview*

View source: R/cfbd_coaches.R

cfbd_coachesR Documentation

CFBD Coaches Endpoint Overview

Description

  • cfbd_coaches(): A coach search function which provides coaching records and school history for a given coach.

  • cfbd_coaches_profile(): Get a single coach's biographical profile.

  • cfbd_coaches_seasons(): Get season-by-season coaching records.

  • cfbd_coaches_tenures(): Get the start and end of each coaching tenure.

Coach information search A coach search function which provides coaching records and school history for a given coach

Usage

cfbd_coaches(
  first = NULL,
  last = NULL,
  team = NULL,
  year = NULL,
  min_year = NULL,
  max_year = NULL
)

Arguments

first

(String optional): First name for the coach you are trying to look up

last

(String optional): Last name for the coach you are trying to look up

team

(String optional): Team - Select a valid team, D1 football

year

(Integer optional): Year, 4 digit format (YYYY).
Minimum value accepted: 1886

min_year

(Integer optional): Minimum Year filter (inclusive), 4 digit format (YYYY).

max_year

(Integer optional): Maximum Year filter (inclusive), 4 digit format (YYYY)

Details

Coach information search

cfbd_coaches(first = "Nick", last = "Saban", team = "alabama")

Get a coach profile

cfbd_coaches_profile(coach_id = 1)

Get coaching seasons

cfbd_coaches_seasons(team = "Georgia")

Get coaching tenures

cfbd_coaches_tenures(team = "Georgia")

Value

Returns a tibble with 15 variables:

col_name types description
first_name character First name of coach.
last_name character Last name of coach.
hire_date character Hire date of coach (ISO date string from CFBD).
school character School of coach for the listed season.
year integer Four-digit season year of record.
games integer Games coached during the season.
wins integer Wins for the season.
losses integer Losses for the season.
ties integer Ties for the season.
preseason_rank integer Preseason AP rank for the school of coach (NA if unranked).
postseason_rank integer Postseason AP rank for the school of coach (NA if unranked).
srs character Simple Rating System adjustment for team.
sp_overall character Bill Connelly's SP+ overall rating for team.
sp_offense character Bill Connelly's SP+ offense rating for team.
sp_defense character Bill Connelly's SP+ defense rating for team.

See Also

Other CFBD Coaches Functions: cfbd_coaches_profile(), cfbd_coaches_seasons(), cfbd_coaches_tenures()

Examples


  try(cfbd_coaches(first = "Nick", last = "Saban", team = "alabama"))


cfbfastR documentation built on Aug. 24, 2026, 5:13 p.m.