cfbd_drives: *CFBD Drives Endpoint Overview*

View source: R/cfbd_drives.R

cfbd_drivesR Documentation

CFBD Drives Endpoint Overview

Description

  • cfbd_drives(): Get college football game drives.

Get college football game drives

Usage

cfbd_drives(
  year,
  season_type = "regular",
  week = NULL,
  team = NULL,
  offense_team = NULL,
  defense_team = NULL,
  conference = NULL,
  offense_conference = NULL,
  defense_conference = NULL,
  division = "fbs"
)

Arguments

year

(Integer required): Year, 4 digit format (YYYY)
Minimum value accepted: 2001

season_type

(String default regular): Season type - regular, postseason, both, allstar, spring_regular, spring_postseason

week

(Integer optional): Week - values from 1-15, 1-14 for seasons pre-playoff, i.e. 2013 or earlier

team

(String optional): D-I Team

offense_team

(String optional): Offense D-I Team

defense_team

(String optional): Defense D-I Team

conference

(String optional): DI Conference abbreviation - Select a valid FBS conference Conference abbreviations P5: ACC, B12, B1G, SEC, PAC Conference abbreviations G5 and FBS Independents: CUSA, MAC, MWC, Ind, SBC, AAC

offense_conference

(String optional): Offense DI Conference abbreviation - Select a valid FBS conference Conference abbreviations P5: ACC, B12, B1G, SEC, PAC Conference abbreviations G5 and FBS Independents: CUSA, MAC, MWC, Ind, SBC, AAC

defense_conference

(String optional): Defense DI Conference abbreviation - Select a valid FBS conference Conference abbreviations P5: ACC, B12, B1G, SEC, PAC Conference abbreviations G5 and FBS Independents: CUSA, MAC, MWC, Ind, SBC, AAC

division

(String optional): Division abbreviation - Select a valid division: fbs/fcs/ii/iii

Details

Get college football game drives

cfbd_drives(year = 2018, week = 1, team = "TCU")

cfbd_drives(2018, team = "Texas A&M", defense_conference = "SEC")

Value

cfbd_drives() - A data frame with 28 variables:

col_name types description
offense character Drive offense team name.
offense_conference character Drive offense team's conference.
defense character Drive defense team name.
defense_conference character Drive defense team's conference.
game_id integer Unique CFBD game identifier.
drive_id character Unique CFBD drive identifier.
drive_number integer Drive number within the game.
scoring logical Flag indicating whether the drive ended in a score.
start_period integer Period (quarter) in which the drive starts.
start_yardline integer Yard line at the drive start.
start_yards_to_goal integer Yards-to-goal at the drive start.
end_period integer Period (quarter) in which the drive ends.
end_yardline integer Yard line at drive end.
end_yards_to_goal integer Yards-to-goal at drive end.
plays integer Number of plays in the drive.
yards integer Total yards gained on the drive.
drive_result character Result of the drive (e.g. TD, FG, PUNT).
is_home_offense logical Flag indicating whether the offense on the field is the home team.
start_offense_score numeric Offense score at the start of the drive.
start_defense_score numeric Defense score at the start of the drive.
end_offense_score numeric Offense score at the end of the drive.
end_defense_score numeric Defense score at the end of the drive.
time_minutes_start integer Game clock minutes at drive start.
time_seconds_start integer Game clock seconds at drive start.
time_minutes_end integer Game clock minutes at drive end.
time_seconds_end integer Game clock seconds at drive end.
time_minutes_elapsed numeric Minutes elapsed during the drive.
time_seconds_elapsed integer Seconds elapsed during the drive.

Examples


  try(cfbd_drives(year=2018, week = 1, team = "TCU"))

  try(cfbd_drives(2018, team = "Texas A&M", defense_conference = "SEC"))


cfbfastR documentation built on Aug. 24, 2026, 5:13 p.m.