| cfbd_metrics | R Documentation |
cfbd_metrics_fg_ep(): Get field goal expected points values.
cfbd_metrics_wepa_team_season(): Get opponent-adjusted team season statistics for predicted points added (PPA).
cfbd_metrics_wepa_players_passing(): Get opponent-adjusted player passing statistics for predicted points added (PPA).
cfbd_metrics_wepa_players_rushing(): Get opponent-adjusted player rushing statistics for predicted points added (PPA).
cfbd_metrics_wepa_players_kicking(): Get Points Added Above Replacement (PAAR) ratings for kickers.
cfbd_metrics_ppa_games(): Get team game averages for predicted points added (PPA).
cfbd_metrics_ppa_players_games(): Get player game averages for predicted points added (PPA).
cfbd_metrics_ppa_players_season(): Get player season averages for predicted points added (PPA).
cfbd_metrics_ppa_predicted(): Calculate predicted points using Down and Distance.
cfbd_metrics_ppa_teams(): Get team averages for predicted points added (PPA).
cfbd_metrics_wp_pregame(): Get pre-game win probability data from CFBD API.
cfbd_metrics_wp(): Get win probability chart data from CFBD API.
cfbd_metrics_fg_ep()
cfbd_metrics_wepa_team_season(year = 2019, team = "TCU")
cfbd_metrics_wepa_players_passing(year = 2019, team = "TCU")
cfbd_metrics_wepa_players_rushing(year = 2019, team = "TCU")
cfbd_metrics_wepa_players_kicking(year = 2019, team = "TCU")
cfbd_metrics_ppa_games(year = 2019, team = "TCU")
cfbd_metrics_ppa_players_games(year = 2019, week = 3, team = "TCU")
cfbd_metrics_ppa_players_season(year = 2019, team = "TCU")
cfbd_metrics_ppa_teams(year = 2019, team = "TCU")
cfbd_metrics_wp_pregame(year = 2019, week = 9, team = "Texas A&M") cfbd_metrics_wp(game_id = 401012356)
cfbd_metrics_ppa_predicted(down = 1, distance = 10)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.