cfbd_metrics_fg_ep: *Get FG expected points from CFBD API*

View source: R/cfbd_metrics.R

cfbd_metrics_fg_epR Documentation

Get FG expected points from CFBD API

Description

Get FG expected points from CFBD API

Usage

cfbd_metrics_fg_ep()

Value

cfbd_metrics_fg_ep() - A data frame with 3 variables:

col_name types description
yards_to_goal integer Yards to the goal line (0-100).
distance integer Distance to goal posts from kicking location (17 yds further than yards to goal).
expected_points numeric Expected points given yards to goal / distance.

See Also

Other CFBD Metrics: cfbd_metrics_ppa_games(), cfbd_metrics_ppa_players_games(), cfbd_metrics_ppa_players_season(), cfbd_metrics_ppa_predicted(), cfbd_metrics_ppa_teams(), cfbd_metrics_wepa_players_kicking(), cfbd_metrics_wepa_players_passing(), cfbd_metrics_wepa_players_rushing(), cfbd_metrics_wepa_team_season(), cfbd_metrics_wp(), cfbd_metrics_wp_pregame()

Examples


  try(cfbd_metrics_fg_ep())


cfbfastR documentation built on Aug. 24, 2026, 5:13 p.m.