cfbd_metrics_wepa_players_kicking: *Get Points Added Above Replacement (PAAR) ratings for...

View source: R/cfbd_metrics.R

cfbd_metrics_wepa_players_kickingR Documentation

Get Points Added Above Replacement (PAAR) ratings for kickers

Description

Get Points Added Above Replacement (PAAR) ratings for kickers

Usage

cfbd_metrics_wepa_players_kicking(year = NULL, team = NULL, conference = NULL)

Arguments

year

(Integer required): Year, 4 digit format (YYYY)
Minimum value accepted: 2016

team

(String optional): D-I Team

conference

(String optional): Conference abbreviation - Select a valid FBS conference Conference abbreviations P5: ACC, B12, B1G, SEC, PAC Conference abbreviations G5 and FBS Independents: CUSA, MAC, MWC, Ind, SBC, AAC

Value

cfbd_metrics_wepa_players_kicking() - A data frame with 7 variables:

col_name types description
year integer Four-digit season year (e.g. 2019).
athlete_id character CFBD athlete identifier (use with cfbd_player_info()).
athlete_name character Kicker full name.
team character Full team name (e.g. "TCU").
conference character Team conference name (e.g. "Big 12").
paar numeric Points Added Above Replacement on field goal attempts (kicker value vs baseline).
attempts integer Total field goal attempts included in the PAAR calculation.

See Also

Other CFBD Metrics: cfbd_metrics_fg_ep(), cfbd_metrics_ppa_games(), cfbd_metrics_ppa_players_games(), cfbd_metrics_ppa_players_season(), cfbd_metrics_ppa_predicted(), cfbd_metrics_ppa_teams(), cfbd_metrics_wepa_players_passing(), cfbd_metrics_wepa_players_rushing(), cfbd_metrics_wepa_team_season(), cfbd_metrics_wp(), cfbd_metrics_wp_pregame()

Examples


  try(cfbd_metrics_wepa_players_kicking(year = 2019, team = "TCU"))


cfbfastR documentation built on Aug. 24, 2026, 5:13 p.m.