cfbd_metrics_wepa_team_season: *Get opponent-adjusted team season statistics for predicted...

View source: R/cfbd_metrics.R

cfbd_metrics_wepa_team_seasonR Documentation

Get opponent-adjusted team season statistics for predicted points added (PPA)

Description

Get opponent-adjusted team season statistics for predicted points added (PPA)

Usage

cfbd_metrics_wepa_team_season(year = NULL, team = NULL, conference = NULL)

Arguments

year

(Integer required): Year, 4 digit format (YYYY)
Minimum value accepted: 2008

team

(String optional): D-I Team

conference

(String optional): Conference abbreviation - Select a valid FBS conference Conference abbreviations P5: ACC, B12, B1G, SEC, PAC Conference abbreviations G5 and FBS Independents: CUSA, MAC, MWC, Ind, SBC, AAC

Value

cfbd_metrics_wepa_team_season() - A data frame with 26 variables:

col_name types description
year integer Four-digit season year (e.g. 2019).
team_id integer CFBD internal team identifier.
team character Full team name (e.g. "TCU").
conference character Team conference name (e.g. "Big 12").
explosiveness numeric Offensive opponent-adjusted explosiveness rate (higher = more big plays).
explosiveness_allowed numeric Defensive opponent-adjusted explosiveness rate allowed.
epa_total numeric Opponent-adjusted total offensive EPA per play (predicted points added).
epa_passing numeric Opponent-adjusted offensive passing EPA per play.
epa_rushing numeric Opponent-adjusted offensive rushing EPA per play.
epa_allowed_total numeric Opponent-adjusted total defensive EPA per play allowed.
epa_allowed_passing numeric Opponent-adjusted defensive passing EPA per play allowed.
epa_allowed_rushing numeric Opponent-adjusted defensive rushing EPA per play allowed.
success_rate_total numeric Opponent-adjusted offensive success rate across all plays (proportion 0-1).
success_rate_standard_downs numeric Opponent-adjusted offensive success rate on standard downs (proportion 0-1).
success_rate_passing_downs numeric Opponent-adjusted offensive success rate on passing downs (proportion 0-1).
success_rate_allowed_total numeric Opponent-adjusted defensive success rate allowed across all plays (proportion 0-1).
success_rate_allowed_standard_downs numeric Opponent-adjusted defensive success rate allowed on standard downs (proportion 0-1).
success_rate_allowed_passing_downs numeric Opponent-adjusted defensive success rate allowed on passing downs (proportion 0-1).
rushing_line_yards numeric Opponent-adjusted offensive line yards per rush (Football Outsiders methodology).
rushing_second_level_yards numeric Opponent-adjusted offensive second-level yards per rush (5-10 yards past line of scrimmage).
rushing_open_field_yards numeric Opponent-adjusted offensive open-field yards per rush (10+ yards past line of scrimmage).
rushing_highlight_yards numeric Opponent-adjusted offensive highlight yards per opportunity rush.
rushing_allowed_line_yards numeric Opponent-adjusted defensive line yards per rush allowed.
rushing_allowed_second_level_yards numeric Opponent-adjusted defensive second-level yards per rush allowed.
rushing_allowed_open_field_yards numeric Opponent-adjusted defensive open-field yards per rush allowed.
rushing_allowed_highlight_yards numeric Opponent-adjusted defensive highlight yards per opportunity rush allowed.

See Also

Other CFBD Metrics: cfbd_metrics_fg_ep(), cfbd_metrics_ppa_games(), cfbd_metrics_ppa_players_games(), cfbd_metrics_ppa_players_season(), cfbd_metrics_ppa_predicted(), cfbd_metrics_ppa_teams(), cfbd_metrics_wepa_players_kicking(), cfbd_metrics_wepa_players_passing(), cfbd_metrics_wepa_players_rushing(), cfbd_metrics_wp(), cfbd_metrics_wp_pregame()

Examples


  try(cfbd_metrics_wepa_team_season(year = 2019, team = "TCU"))


cfbfastR documentation built on Aug. 24, 2026, 5:13 p.m.