cfbd_player_info: *Player information lookup*

View source: R/cfbd_players.R

cfbd_player_infoR Documentation

Player information lookup

Description

Player information lookup

Usage

cfbd_player_info(search_term, position = NULL, team = NULL, year = NULL)

Arguments

search_term

(String required): Search term for the player you are trying to look up

position

(string optional): Position of the player you are searching for. Position Group - options include:

  • Offense: QB, RB, FB, TE, OL, G, OT, C, WR

  • Defense: DB, CB, S, LB, DE, DT, NT, DL

  • Special Teams: K, P, LS, PK

team

(String optional): Team - Select a valid team, D1 football

year

(Integer optional): Year, 4 digit format (YYYY). If left NULL, API default will only provide results for most recent year of final rosters: 2020
Minimum value accepted: 2004

Value

cfbd_player_info() - A data frame with 12 variables:

col_name types description
athlete_id character Unique CFBD player identifier.
team character Team of the player.
name character Player full name.
first_name character Player first name.
last_name character Player last name.
weight integer Player weight in pounds.
height integer Player height in inches.
jersey integer Player jersey number.
position character Player position abbreviation (e.g. QB, RB, WR).
home_town character Player home town.
team_color character Player team primary color (hex code).
team_color_secondary character Player team secondary color (hex code).

See Also

Other CFBD Players: cfbd_player_returning(), cfbd_player_usage()

Examples


  try(cfbd_player_info(search_term = "James", position = "DB", team = "Florida State", year = 2017))

  try(cfbd_player_info(search_term = "Lawrence", team = "Clemson"))


cfbfastR documentation built on Aug. 24, 2026, 5:13 p.m.