cfbd_player_usage: *Get player usage metrics*

View source: R/cfbd_players.R

cfbd_player_usageR Documentation

Get player usage metrics

Description

Get player usage metrics

Usage

cfbd_player_usage(
  year = most_recent_cfb_season(),
  team = NULL,
  conference = NULL,
  position = NULL,
  athlete_id = NULL,
  excl_garbage_time = FALSE
)

Arguments

year

(Integer required, default most recent season): Year, 4 digit format (YYYY).
Minimum value accepted: 2013

team

(String optional): Team - Select a valid team, D1 football

conference

(String optional): Conference abbreviation - Select a valid FBS conference Conference abbreviations P5: ACC, B12, B1G, SEC, PAC Conference abbreviations G5 and FBS Independents: CUSA, MAC, MWC, Ind, SBC, AAC

position

(string optional): Position of the player you are searching for. Position Group - options include:

  • Offense: QB, RB, FB, TE, OL, G, OT, C, WR

  • Defense: DB, CB, S, LB, DE, DT, NT, DL

  • Special Teams: K, P, LS, PK

athlete_id

(Integer optional): Athlete ID filter for querying a single athlete Can be found using the cfbd_player_info() function.

excl_garbage_time

(Logical default FALSE): Select whether to exclude Garbage Time (TRUE/FALSE)

Value

cfbd_player_usage() - A data frame with 14 variables:

col_name types description
season integer Four-digit season year for player usage.
athlete_id character Unique CFBD athlete identifier.
name character Athlete full name.
position character Athlete position abbreviation (e.g. QB, RB, WR).
team character Team name.
conference character Conference of team.
usg_overall numeric Player share of overall offensive usage.
usg_pass numeric Player share of team passing usage.
usg_rush numeric Player share of team rushing usage.
usg_1st_down numeric Player share of team usage on first downs.
usg_2nd_down numeric Player share of team usage on second downs.
usg_3rd_down numeric Player share of team usage on third downs.
usg_standard_downs numeric Player share of team usage on standard downs.
usg_passing_downs numeric Player share of team usage on passing downs.

See Also

Other CFBD Players: cfbd_player_info(), cfbd_player_returning()

Examples


  try(cfbd_player_usage(year = 2019, position = "WR", team = "Florida State"))



cfbfastR documentation built on Aug. 24, 2026, 5:13 p.m.