cfbd_ratings_elo: *Get Elo historical rating data*

View source: R/cfbd_ratings.R

cfbd_ratings_eloR Documentation

Get Elo historical rating data

Description

Acquire the CFBD calculated elo ratings data by team, year, week, and conference

Usage

cfbd_ratings_elo(
  year = NULL,
  week = NULL,
  season_type = "both",
  team = NULL,
  conference = NULL
)

Arguments

year

(Integer optional): Year, 4 digit format (YYYY)
Minimum value accepted: 1890

week

(Integer optional): Maximum Week of ratings.

season_type

(String default both): Season type - regular, postseason, both, allstar, spring_regular, spring_postseason

team

(String optional): D-I Team

conference

(String optional): Conference abbreviation - Elo information by conference Conference abbreviations P5: ACC, B12, B1G, SEC, PAC Conference abbreviations G5 and FBS Independents: CUSA, MAC, MWC, Ind, SBC, AAC

Value

cfbd_ratings_elo() - A data frame with 4 variables:

col_name types description
year integer Four-digit season year (e.g. 2019).
team character Full team name (e.g. "Texas").
conference character Conference affiliation for the team in the given season.
elo numeric CFBD-calculated Elo rating for the team as of the requested week.

See Also

Other CFBD Ratings and Rankings: cfbd_rankings(), cfbd_ratings_fpi(), cfbd_ratings_sp(), cfbd_ratings_sp_conference(), cfbd_ratings_srs()

Examples


  try(cfbd_ratings_elo(year = 2019, team = "Texas"))

  try(cfbd_ratings_elo(year = 2018, conference = "SEC"))



cfbfastR documentation built on Aug. 24, 2026, 5:13 p.m.