cfbd_ratings_sp_conference: *Get conference level SP historical rating data*

View source: R/cfbd_ratings.R

cfbd_ratings_sp_conferenceR Documentation

Get conference level SP historical rating data

Description

Get conference level SP historical rating data

Usage

cfbd_ratings_sp_conference(year = NULL, conference = NULL, division = NULL)

Arguments

year

(Integer optional): Year, 4 digit format (YYYY)
Minimum value accepted: 1970

conference

(String optional): Conference abbreviation - S&P+ information by conference Conference abbreviations P5: ACC, B12, B1G, SEC, PAC Conference abbreviations G5 and FBS Independents: CUSA, MAC, MWC, Ind, SBC, AAC

division

(String optional): Division/classification filter – one of fbs, fcs, ii, ii/iii, iii. Sent to CFBD as classification.

Value

cfbd_ratings_sp_conference() - A data frame with 25 variables:

col_name types description
year integer Season of the conference rating.
conference character Conference name.
rating numeric Conference SP+ rating.
second_order_wins logical Second-order wins for the conference - Not available for recent seasons.
sos logical Strength of schedule for the conference - Not available for recent seasons.
offense_rating numeric Overall offense rating for the conference.
offense_success logical Offense success rating for the conference - Not available for recent seasons.
offense_explosiveness logical Offense explosiveness rating for the conference - Not available for recent seasons.
offense_rushing logical Offense rushing rating for the conference - Not available for recent seasons.
offense_passing logical Offense passing rating for the conference - Not available for recent seasons.
offense_standard_downs logical Offense standard downs rating for the conference - Not available for recent seasons.
offense_passing_downs logical Offensive passing downs rating for the conference - Not available for recent seasons.
offense_run_rate logical Offense rushing rate for the conference - Not available for recent seasons.
offense_pace logical Offense pace factor for the conference - Not available for recent seasons.
defense_ranking integer Overall defense ranking for the conference.
defense_rating numeric Overall defense rating for the conference.
defense_success logical Defense success rating for the conference - Not available for recent seasons.
defense_explosiveness logical Defense explosiveness rating for the conference - Not available for recent seasons.
defense_rushing logical Defense rushing rating for the conference - Not available for recent seasons.
defense_passing logical Defense passing rating for the conference - Not available for recent seasons.
defense_standard_downs logical Defense standard downs rating for the conference - Not available for recent seasons.
defense_passing_downs logical Defensive passing downs rating for the conference - Not available for recent seasons.
defense_havoc_total logical Total defensive havoc rate for the conference - Not available for recent seasons.
defense_havoc_front_seven logical Defense havoc rate from front 7 players for the conference - Not available for recent seasons.
defense_havoc_db logical Defense havoc rate from defensive backs for the conference - Not available for recent seasons.
special_teams_rating numeric Special teams rating for the conference.

See Also

Other CFBD Ratings and Rankings: cfbd_rankings(), cfbd_ratings_elo(), cfbd_ratings_fpi(), cfbd_ratings_sp(), cfbd_ratings_srs()

Examples


  try(cfbd_ratings_sp_conference(year = 2019))

  try(cfbd_ratings_sp_conference(year = 2012, conference = "SEC"))

  try(cfbd_ratings_sp_conference(year = 2016, conference = "ACC"))



cfbfastR documentation built on Aug. 24, 2026, 5:13 p.m.