cfbd_ratings_srs: *Get SRS historical rating data*

View source: R/cfbd_ratings.R

cfbd_ratings_srsR Documentation

Get SRS historical rating data

Description

At least one of year or team must be specified for the function to run

Usage

cfbd_ratings_srs(year = NULL, team = NULL, conference = NULL)

Arguments

year

(Integer optional): Year, 4 digit format (YYYY). Required if team not provided
Minimum value accepted: 1897

team

(String optional): D-I Team. Required if year not provided

conference

(String optional): Conference abbreviation - SRS information by conference Conference abbreviations P5: ACC, B12, B1G, SEC, PAC Conference abbreviations G5 and FBS Independents: CUSA, MAC, MWC, Ind, SBC, AAC

Value

cfbd_ratings_srs() - A data frame with 6 variables:

col_name types description
year integer Season of the SRS rating.
team character Team name.
conference character Conference of the team.
division character Division in the conference for the team.
rating numeric Simple Rating System (SRS) rating.
ranking integer Simple Rating System ranking within the group returned.

See Also

Other CFBD Ratings and Rankings: cfbd_rankings(), cfbd_ratings_elo(), cfbd_ratings_fpi(), cfbd_ratings_sp(), cfbd_ratings_sp_conference()

Examples


  try(cfbd_ratings_srs(year = 2019, team = "Texas"))

  try(cfbd_ratings_srs(year = 2018, conference = "SEC"))



cfbfastR documentation built on Aug. 24, 2026, 5:13 p.m.