cfbd_recruiting_player: *Get player recruiting rankings*

View source: R/cfbd_recruiting.R

cfbd_recruiting_playerR Documentation

Get player recruiting rankings

Description

Get player recruiting rankings

Usage

cfbd_recruiting_player(
  year = NULL,
  team = NULL,
  recruit_type = "HighSchool",
  state = NULL,
  position = NULL,
  division = NULL
)

Arguments

year

(Integer optional): Year, 4 digit format (YYYY) Required if team not provided
Minimum value accepted: 2000

team

(String optional): D-I Team. Required if year not provided

recruit_type

(String optional): default API return is 'HighSchool', other options include 'JUCO' or 'PrepSchool' - For position group information

state

(String optional): Two letter State abbreviation

position

(String optional): Position Group - options include:

  • Offense: 'PRO', 'DUAL', 'RB', 'FB', 'TE', 'OT', 'OG', 'OC', 'WR'

  • Defense: 'CB', 'S', 'OLB', 'ILB', 'WDE', 'SDE', 'DT'

  • Special Teams: 'K', 'P'

division

(String optional): Division/classification filter – one of fbs, fcs, ii, ii/iii, iii. Sent to CFBD as classification.

Value

cfbd_recruiting_player() - A data frame with 19 variables:

col_name types description
id integer 247Sports referencing id for the recruit.
athlete_id integer CFBD athlete referencing id linking to player tables.
recruit_type character Recruit class: High School, Prep School, or Junior College.
year integer Recruiting class year (four-digit season).
ranking integer Recruit national ranking within the class.
name character Recruit full name.
school character High school, prep school, or JUCO program the recruit attended.
committed_to character College program the recruit is committed to.
position character Recruit position abbreviation (e.g. QB, WR, OT).
height numeric Recruit height in inches.
weight integer Recruit weight in pounds.
stars integer Recruit star rating on the 247Sports scale (2-5).
rating numeric 247Sports composite rating for the recruit.
city character Hometown city of the recruit.
state_province character Hometown state or province of the recruit.
country character Hometown country of the recruit.
hometown_info_latitude character Latitude of the recruit's hometown.
hometown_info_longitude character Longitude of the recruit's hometown.
hometown_info_fips_code character FIPS code of the recruit's hometown.

See Also

Other CFBD Recruiting: cfbd_recruiting_position(), cfbd_recruiting_team(), cfbd_recruiting_transfer_portal()

Examples


  try(cfbd_recruiting_player(2018, team = "Texas"))

  try(cfbd_recruiting_player(2016, recruit_type = "JUCO"))

  try(cfbd_recruiting_player(2020, recruit_type = "HighSchool", position = "OT", state = "FL"))



cfbfastR documentation built on Aug. 24, 2026, 5:13 p.m.