cfbd_recruiting_position: *Get college football position group recruiting information.*

View source: R/cfbd_recruiting.R

cfbd_recruiting_positionR Documentation

Get college football position group recruiting information.

Description

Get college football position group recruiting information.

Usage

cfbd_recruiting_position(
  start_year = NULL,
  end_year = NULL,
  team = NULL,
  conference = NULL,
  recruit_type = NULL
)

Arguments

start_year

(Integer optional): Start Year, 4 digit format (YYYY). Note: 2000 is the minimum value

end_year

(Integer optional): End Year, 4 digit format (YYYY). Note: 2020 is the maximum value currently

team

(String optional): Team - Select a valid team, D-I football

conference

(String optional): Conference abbreviation - Select a valid FBS conference Conference abbreviations P5: ACC, B12, B1G, SEC, PAC Conference abbreviations G5 and FBS Independents: CUSA, MAC, MWC, Ind, SBC, AAC

recruit_type

(String optional): HighSchool, PrepSchool or JUCO.

Value

cfbd_recruiting_position() - A data frame with 7 variables:

col_name types description
team character Recruiting team (school) name.
conference character Conference affiliation of the recruiting team.
position_group character Position group of the recruits (e.g. Offensive Line, Defensive Back).
avg_rating numeric Average 247Sports composite rating of recruits in the position group.
total_rating numeric Sum of the 247Sports composite ratings of recruits in the group.
commits integer Number of commits in the position group.
avg_stars numeric Average star rating of recruits in the position group.

See Also

Other CFBD Recruiting: cfbd_recruiting_player(), cfbd_recruiting_team(), cfbd_recruiting_transfer_portal()

Examples


  try(cfbd_recruiting_position(2018, team = "Texas"))

  try(cfbd_recruiting_position(2016, 2020, team = "Virginia"))

  try(cfbd_recruiting_position(2015, 2020, conference = "SEC"))



cfbfastR documentation built on Aug. 24, 2026, 5:13 p.m.