cfbd_team_matchup_records: *Get matchup history records between two teams.*

View source: R/cfbd_teams.R

cfbd_team_matchup_recordsR Documentation

Get matchup history records between two teams.

Description

Get matchup history records between two teams.

Usage

cfbd_team_matchup_records(team1, team2, min_year = NULL, max_year = NULL)

Arguments

team1

(String required): D-I Team 1

team2

(String required): D-I Team 2

min_year

(Integer optional): Minimum of year range, 4 digit format (YYYY)

max_year

(Integer optional): Maximum of year range, 4 digit format (YYYY)

Value

cfbd_team_matchup_records() - A data frame with 7 variables:

col_name types description
start_year integer Span starting year.
end_year integer Span ending year.
team1 character First team selected in query.
team1_wins integer First team wins in series against team2.
team2 character Second team selected in query.
team2_wins integer Second team wins in series against team1.
ties integer Number of ties in the series.

See Also

Other CFBD Teams: cfbd_team_info(), cfbd_team_matchup(), cfbd_team_roster(), cfbd_team_talent()

Examples


  try(cfbd_team_matchup_records("Texas", "Oklahoma"))

  try(cfbd_team_matchup_records("Texas A&M", "TCU", min_year = 1975))



cfbfastR documentation built on Aug. 24, 2026, 5:13 p.m.