cfbd_team_talent: *Get composite team talent rankings for all teams in a given...

View source: R/cfbd_teams.R

cfbd_team_talentR Documentation

Get composite team talent rankings for all teams in a given year

Description

Extracts team talent composite as sourced from 247 rankings

Usage

cfbd_team_talent(year = most_recent_cfb_season())

Arguments

year

(Integer optional): Year 4 digit format (YYYY)
Minimum value accepted: 2015

Value

cfbd_team_talent() - A data frame with 3 variables:

col_name types description
year integer Season for the talent rating.
school character Team name.
talent numeric Overall roster talent points (as determined by 247Sports).

See Also

Other CFBD Teams: cfbd_team_info(), cfbd_team_matchup(), cfbd_team_matchup_records(), cfbd_team_roster()

Examples


  try(cfbd_team_talent())

  try(cfbd_team_talent(year = 2018))



cfbfastR documentation built on Aug. 24, 2026, 5:13 p.m.