espn_cfb_season_types: *ESPN College Football Season Types*

View source: R/espn_cfb_season.R

espn_cfb_season_typesR Documentation

ESPN College Football Season Types

Description

Get the set of season types (preseason, regular season, postseason, off-season) ESPN tracks for a college football season, including each type's date window and capability flags.

Usage

espn_cfb_season_types(year = NULL)

Arguments

year

(Integer required): Season, 4 digit format (YYYY).
Minimum value accepted: 1872

Details

Wraps the ESPN core-v2 endpoint sports.core.api.espn.com/v2/sports/football/leagues/college-football/seasons/{year}/types. The index returns one ⁠$ref⁠ per season type; this wrapper dereferences each and returns one row per type (typically four: 1 preseason, 2 regular season, 3 postseason, 4 off-season). The season_type ids returned here are the values other Batch 5 wrappers (espn_cfb_season_weeks(), espn_cfb_groups(), espn_cfb_standings(), espn_cfb_week_rankings()) accept as their season_type argument.

Value

A data frame with one row per season type:

col_name types description
season integer Season (4-digit year).
season_type integer ESPN season type id (1 pre, 2 reg, 3 post, 4 off).
type integer Season type code (mirrors season_type).
name character Season type name (e.g. ⁠Regular Season⁠).
abbreviation character Season type abbreviation (e.g. reg).
slug character Season type slug (e.g. regular-season).
start_date character Season type start timestamp (ISO 8601, UTC).
end_date character Season type end timestamp (ISO 8601, UTC).
has_groups logical Whether the season type exposes a groups resource.
has_standings logical Whether the season type exposes standings.
type_ref character ⁠$ref⁠ URL to the season type resource.

See Also

Other ESPN CFB Functions: espn_cfb_award(), espn_cfb_awards(), espn_cfb_clear_cache(), espn_cfb_coach(), espn_cfb_coach_record(), espn_cfb_coaches(), espn_cfb_franchise(), espn_cfb_franchises(), espn_cfb_futures(), espn_cfb_game_broadcasts(), espn_cfb_game_drive_plays(), espn_cfb_game_drives(), espn_cfb_game_leaders(), espn_cfb_game_odds(), espn_cfb_game_pbp(), espn_cfb_game_play(), espn_cfb_game_player_box(), espn_cfb_game_player_statistics(), espn_cfb_game_powerindex(), espn_cfb_game_predictor(), espn_cfb_game_probabilities(), espn_cfb_game_situation(), espn_cfb_game_status(), espn_cfb_game_team_leaders(), espn_cfb_game_team_linescores(), espn_cfb_game_team_records(), espn_cfb_game_team_roster(), espn_cfb_game_team_statistics(), espn_cfb_game_teams(), espn_cfb_groups(), espn_cfb_pbp_v2(), espn_cfb_player(), espn_cfb_player_career_stats(), espn_cfb_player_eventlog(), espn_cfb_player_gamelog(), espn_cfb_player_overview(), espn_cfb_player_seasons(), espn_cfb_player_splits(), espn_cfb_player_stats_v3(), espn_cfb_players(), espn_cfb_position(), espn_cfb_positions(), espn_cfb_powerindex(), espn_cfb_qbr(), espn_cfb_rankings(), espn_cfb_recruits(), espn_cfb_season_info(), espn_cfb_season_weeks(), espn_cfb_seasons(), espn_cfb_standings(), espn_cfb_team(), espn_cfb_team_ats(), espn_cfb_team_awards(), espn_cfb_team_coaches(), espn_cfb_team_events(), espn_cfb_team_leaders(), espn_cfb_team_powerindex(), espn_cfb_team_ranks(), espn_cfb_team_record(), espn_cfb_team_roster(), espn_cfb_team_schedule(), espn_cfb_teams(), espn_cfb_unnest_plays(), espn_cfb_venue(), espn_cfb_venues(), espn_cfb_week_rankings()

Examples


  try(espn_cfb_season_types(year = 2024))


cfbfastR documentation built on Aug. 24, 2026, 5:13 p.m.