espn_metrics: *ESPN Metrics*

espn_metricsR Documentation

ESPN Metrics

Description

ESPN Metrics

Get win probability chart data from ESPN Graciously contributed by MrCaseB:

Usage

espn_metrics_wp(game_id)

Arguments

game_id

(Integer required): Game ID filter for querying a single game Can be found using the cfbd_game_info() function

Value

espn_metrics_wp() - A data frame with 5 variables:

  • game_id: character. Referencing game ID (should be same as game_id from other functions).

  • play_id: character. Referencing play ID.

  • seconds_left: integer. DEPRECATED. Seconds left in the game.

  • home_win_percentage: double. The probability of the home team winning the game.

  • away_win_percentage: double. The probability of the away team winning the game (calculated as 1 - home_win_percentage - tie_percentage).

  • tie_percentage: double. The probability of the game ending the final period in a tie.

Examples


  try(espn_metrics_wp(game_id = 401628369))



cfbfastR documentation built on Aug. 24, 2026, 5:13 p.m.