cfbd_game_team_stats: *Get team statistics by game*

View source: R/cfbd_games.R

cfbd_game_team_statsR Documentation

Get team statistics by game

Description

Get team statistics by game

Usage

cfbd_game_team_stats(
  year,
  week = NULL,
  season_type = "regular",
  team = NULL,
  conference = NULL,
  game_id = NULL,
  division = "fbs",
  rows_per_team = 1
)

Arguments

year

(Integer required): Year, 4 digit format (YYYY). Required year filter (along with one of week, team, or conference), unless game_id is specified
Minimum value accepted: 2004

week

(Integer optional): Week - values range from 1-15, 1-14 for seasons pre-playoff, i.e. 2013 or earlier. Required if team and conference not specified.

season_type

(String default: regular): Select Season Type - regular, postseason, both, allstar, spring_regular, spring_postseason

team

(String optional): D-I Team. Required if week and conference not specified.

conference

(String optional): Conference abbreviation - Select a valid FBS conference Conference abbreviations P5: ACC, B12, B1G, SEC, PAC Conference abbreviations G5 and FBS Independents: CUSA, MAC, MWC, Ind, SBC, AAC Required if week and team not specified.

game_id

(Integer optional): Game ID filter for querying a single game Can be found using the cfbd_game_info() function

division

(String optional): Division abbreviation - Select a valid division: fbs/fcs/ii/iii

rows_per_team

(Integer default 1): Both Teams for each game on one or two row(s), Options: 1 or 2

Value

cfbd_game_team_stats() - A data frame with 78 variables:

col_name types description
game_id integer Referencing game id.
team character Team name.
conference character Conference of the team.
home_away character Home/Away Flag.
opponent character Opponent team name.
opponent_conference character Conference of the opponent team.
points integer Team points.
total_yards character Team total yards.
net_passing_yards character Team net passing yards.
completion_attempts character Team completion attempts.
passing_tds character Team passing touchdowns.
yards_per_pass character Team game yards per pass.
passes_intercepted character Team passes intercepted.
interception_yards character Interception yards.
interception_tds character Interceptions returned for a touchdown.
rushing_attempts character Team rushing attempts.
rushing_yards character Team rushing yards.
rush_tds character Team rushing touchdowns.
yards_per_rush_attempt character Team yards per rush attempt.
first_downs character First downs earned by the team.
third_down_eff character Third down efficiency.
fourth_down_eff character Fourth down efficiency.
punt_returns character Team punt returns.
punt_return_yards character Team punt return yards.
punt_return_tds character Team punt return touchdowns.
kick_return_yards character Team kick return yards.
kick_return_tds character Team kick return touchdowns.
kick_returns character Team kick returns.
kicking_points character Team points from kicking the ball.
fumbles_recovered character Team fumbles recovered.
fumbles_lost character Team fumbles lost.
total_fumbles character Team total fumbles.
tackles character Team tackles.
tackles_for_loss character Team tackles for a loss.
sacks character Team sacks.
qb_hurries character Team QB hurries.
interceptions character Team interceptions.
passes_deflected character Team passes deflected.
turnovers character Team turnovers.
defensive_tds character Team defensive touchdowns.
total_penalties_yards character Team total penalty yards.
possession_time character Team time of possession.
points_allowed integer Points for the opponent.
total_yards_allowed character Opponent total yards.
net_passing_yards_allowed character Opponent net passing yards.
completion_attempts_allowed character Opponent completion attempts.
passing_tds_allowed character Opponent passing TDs.
yards_per_pass_allowed character Opponent yards per pass allowed.
passes_intercepted_allowed character Opponent passes intercepted.
interception_yards_allowed character Opponent interception yards.
interception_tds_allowed character Opponent interception TDs.
rushing_attempts_allowed character Opponent rushing attempts.
rushing_yards_allowed character Opponent rushing yards.
rush_tds_allowed character Opponent rushing touchdowns.
yards_per_rush_attempt_allowed character Opponent rushing yards per attempt.
first_downs_allowed character Opponent first downs.
third_down_eff_allowed character Opponent third down efficiency.
fourth_down_eff_allowed character Opponent fourth down efficiency.
punt_returns_allowed character Opponent punt returns.
punt_return_yards_allowed character Opponent punt return yards.
punt_return_tds_allowed character Opponent punt return touchdowns.
kick_return_yards_allowed character Opponent kick return yards.
kick_return_tds_allowed character Opponent kick return touchdowns.
kick_returns_allowed character Opponent kick returns.
kicking_points_allowed character Opponent points from kicking.
fumbles_recovered_allowed character Opponent fumbles recovered.
fumbles_lost_allowed character Opponent fumbles lost.
total_fumbles_allowed character Opponent total number of fumbles.
tackles_allowed character Opponent tackles.
tackles_for_loss_allowed character Opponent tackles for loss.
sacks_allowed character Opponent sacks.
qb_hurries_allowed character Opponent quarterback hurries.
interceptions_allowed character Opponent interceptions.
passes_deflected_allowed character Opponent passes deflected.
turnovers_allowed character Opponent turnovers.
defensive_tds_allowed character Opponent defensive touchdowns.
total_penalties_yards_allowed character Opponent total penalty yards.
possession_time_allowed character Opponent time of possession.

See Also

Other CFBD Games: cfbd_calendar(), cfbd_game_box_advanced(), cfbd_game_info(), cfbd_game_media(), cfbd_game_player_stats(), cfbd_game_records(), cfbd_game_weather(), cfbd_live_scoreboard()

Examples


  try(cfbd_game_team_stats(2022, team = "LSU"))

  try(cfbd_game_team_stats(2013, team = "Florida State"))


cfbfastR documentation built on Aug. 24, 2026, 5:13 p.m.