| cfbd_metrics_ppa_players_games | R Documentation |
Get player game averages for predicted points added (PPA)
cfbd_metrics_ppa_players_games(
year = NULL,
week = NULL,
season_type = "both",
team = NULL,
position = NULL,
athlete_id = NULL,
threshold = NULL,
excl_garbage_time = FALSE
)
year |
(Integer required): Year, 4 digit format (YYYY). |
week |
(Integer optional): Week - values range from 1-15, 1-14 for seasons pre-playoff, i.e. 2013 or earlier. Required if team not provided. |
season_type |
(String default both): Season type - regular, postseason, both, allstar, spring_regular, spring_postseason |
team |
(String optional): D-I Team. Required if week not provided. |
position |
(string optional): Position abbreviation of the player you are searching for. Position Group - options include:
|
athlete_id |
(Integer optional): Athlete ID filter for querying a single athlete
Can be found using the |
threshold |
(Integer optional): Minimum threshold of plays. |
excl_garbage_time |
(Logical default FALSE): Select whether to exclude Garbage Time (TRUE or FALSE) |
cfbd_metrics_ppa_players_games() - A data frame with 10 variables:
| col_name | types | description |
| season | integer | Season of the game. |
| week | integer | Game week of the season. |
| athlete_id | character | Athlete referencing id. |
| name | character | Athlete name. |
| position | character | Athlete position. |
| team | character | Team name. |
| opponent | character | Team opponent name. |
| avg_PPA_all | numeric | Average overall predicted points added (PPA). |
| avg_PPA_pass | numeric | Average passing predicted points added (PPA). |
| avg_PPA_rush | numeric | Average rushing predicted points added (PPA). |
Other CFBD Metrics:
cfbd_metrics_fg_ep(),
cfbd_metrics_ppa_games(),
cfbd_metrics_ppa_players_season(),
cfbd_metrics_ppa_predicted(),
cfbd_metrics_ppa_teams(),
cfbd_metrics_wepa_players_kicking(),
cfbd_metrics_wepa_players_passing(),
cfbd_metrics_wepa_players_rushing(),
cfbd_metrics_wepa_team_season(),
cfbd_metrics_wp(),
cfbd_metrics_wp_pregame()
try(cfbd_metrics_ppa_players_games(year = 2019, week = 3, team = "TCU"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.