| cfbd_metrics_wepa_players_passing | R Documentation |
Get opponent-adjusted player passing statistics for predicted points added (PPA)
cfbd_metrics_wepa_players_passing(
year = NULL,
team = NULL,
conference = NULL,
position = NULL
)
year |
(Integer required): Year, 4 digit format (YYYY) |
team |
(String optional): D-I Team |
conference |
(String optional): Conference abbreviation - Select a valid FBS conference Conference abbreviations P5: ACC, B12, B1G, SEC, PAC Conference abbreviations G5 and FBS Independents: CUSA, MAC, MWC, Ind, SBC, AAC |
position |
(string optional): Position abbreviation of the player you are searching for. Position Group - options include:
|
cfbd_metrics_wepa_players_passing() - A data frame with 8 variables:
| col_name | types | description |
| year | integer | Four-digit season year (e.g. 2019). |
| athlete_id | character | CFBD athlete identifier (use with cfbd_player_info()). |
| athlete_name | character | Player full name. |
| position | character | Player position abbreviation (e.g. "QB", "RB"). |
| team | character | Full team name (e.g. "TCU"). |
| conference | character | Team conference name (e.g. "Big 12"). |
| wepa | numeric | Opponent-adjusted weighted EPA (passing predicted points added). |
| plays | integer | Total qualifying passing plays included in the WEPA calculation. |
Other CFBD Metrics:
cfbd_metrics_fg_ep(),
cfbd_metrics_ppa_games(),
cfbd_metrics_ppa_players_games(),
cfbd_metrics_ppa_players_season(),
cfbd_metrics_ppa_predicted(),
cfbd_metrics_ppa_teams(),
cfbd_metrics_wepa_players_kicking(),
cfbd_metrics_wepa_players_rushing(),
cfbd_metrics_wepa_team_season(),
cfbd_metrics_wp(),
cfbd_metrics_wp_pregame()
try(cfbd_metrics_wepa_players_passing(year = 2019, team = "TCU"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.