View source: R/cfbd_playoffs.R
| cfbd_playoffs_cfp_games | R Documentation |
Get College Football Playoff games Returns the games played in the College Football Playoff for a season.
cfbd_playoffs_cfp_games(year, round = NULL, proxy = NULL)
year |
(Integer required): Season, 4 digits (YYYY). |
round |
(String optional): |
proxy |
(List optional): Per-call proxy override passed to
|
cfbd_playoffs_cfp_games() - A tibble with 34 columns:
| col_name | types | description |
| id | integer | Record identifier. |
| bracket_slot | character | Bracket position code for the matchup (e.g. FR1, QF2). |
| round | character | Playoff round code. |
| round_name | character | Human-readable playoff round name. |
| round_order | integer | Ordinal position of the round in the bracket. |
| matchup_order | integer | Ordinal position of the matchup within its round. |
| start_date | character | Scheduled start date and time (ISO 8601). |
| bowl_name | character | Bowl or site name hosting the matchup. |
| game_id | integer | Referencing game id. |
| game_start_date | character | Game scheduled start date and time (ISO 8601). |
| game_completed | logical | Game completion flag. |
| game_home_points | integer | Game home points. |
| game_away_points | integer | Game away points. |
| game_venue_id | integer | Game referencing venue id. |
| game_venue | character | Game venue name. |
| game_home_team_id | integer | Home team identifier. |
| game_home_team_school | character | Home team school name. |
| game_home_team_conference | character | Home team conference. |
| game_away_team_id | integer | Away team identifier. |
| game_away_team_school | character | Away team school name. |
| game_away_team_conference | character | Away team conference. |
| advances_to_matchup_id | integer | Next-matchup matchup id. |
| advances_to_bracket_slot | character | Next-matchup bracket position code for the matchup (e.g. FR1, QF2). |
| advances_to_position | integer | Next-matchup bracket position. |
| slot1_position | integer | First bracket slot bracket position. |
| slot1_seed | integer | First bracket slot seed. |
| slot1_team_id | integer | First bracket slot referencing team id. |
| slot1_school | character | First bracket slot school name. |
| slot1_conference | character | First bracket slot conference. |
| slot2_position | integer | Second bracket slot bracket position. |
| slot2_seed | integer | Second bracket slot seed. |
| slot2_team_id | integer | Second bracket slot referencing team id. |
| slot2_school | character | Second bracket slot school name. |
| slot2_conference | character | Second bracket slot conference. |
Other CFBD Playoff Functions:
cfbd_playoffs_cfp(),
cfbd_playoffs_cfp_participants()
try(cfbd_playoffs_cfp_games(year = 2024))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.