View source: R/cfbd_playoffs.R
| cfbd_playoffs_cfp_participants | R Documentation |
Get College Football Playoff participants Returns the teams that participated in the College Football Playoff for a season.
cfbd_playoffs_cfp_participants(year, proxy = NULL)
year |
(Integer required): Season, 4 digits (YYYY). |
proxy |
(List optional): Per-call proxy override passed to
|
cfbd_playoffs_cfp_participants() - A tibble with 12 columns:
| col_name | types | description |
| committee_rank | integer | Selection-committee rank. |
| seed | integer | Seed in the bracket. |
| bid_type | character | How the team qualified (automatic or at_large). |
| qualification_reason | character | Stated reason the team qualified. |
| conference_champion | logical | TRUE if the team won its conference. |
| qualifying_conference | character | Conference through which the team qualified. |
| first_round_bye | logical | TRUE if the team received a first-round bye. |
| outcome | character | Outcome of the team's playoff run. |
| eliminated_round | character | Round in which the team was eliminated. |
| team_id | integer | Referencing team id. |
| team_school | character | School name of the team. |
| team_conference | character | Conference the team belongs to. |
Other CFBD Playoff Functions:
cfbd_playoffs_cfp(),
cfbd_playoffs_cfp_games()
try(cfbd_playoffs_cfp_participants(year = 2024))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.