cfbd_venues: *CFBD Venues Endpoint Overview*

View source: R/cfbd_venues.R

cfbd_venuesR Documentation

CFBD Venues Endpoint Overview

Description

  • cfbd_venues(): Pulls all college football venues and data on capacity, grass, city/state, location, elevation, dome, timezone and construction year.

Pulls all college football venues and data on capacity, grass, city/state, location, elevation, dome, timezone and construction year.

Usage

cfbd_venues()

Details

CFB Venue Information

cfbd_venues()

CFB Venue Information

 cfbd_venues()

Value

A data frame with 337 rows and 14 variables:

col_name types description
venue_id integer Referencing venue ID.
name character Venue name.
capacity integer Stadium capacity.
grass logical TRUE/FALSE response on whether the field is grass or not.
city character Venue city.
state character Venue state.
zip character Venue zip code.
country_code character Venue country code.
latitude numeric Venue latitude in decimal degrees.
longitude numeric Venue longitude in decimal degrees.
elevation character Venue elevation above sea level.
year_constructed integer Year in which the venue was constructed.
dome logical TRUE/FALSE response to whether the venue has a dome or not.
timezone character Time zone in which the venue resides (i.e. Eastern Time -> "America/New_York").

Examples


  try(cfbd_venues())


cfbfastR documentation built on Aug. 24, 2026, 5:13 p.m.