| cfbd_venues | R Documentation |
cfbd_venues(): Pulls all college football venues and data on capacity, grass, city/state, location, elevation, dome, timezone and construction year.
Pulls all college football venues and data on capacity, grass, city/state, location, elevation, dome, timezone and construction year.
cfbd_venues()
cfbd_venues()
CFB Venue Information
cfbd_venues()
A data frame with 337 rows and 14 variables:
| col_name | types | description |
| venue_id | integer | Referencing venue ID. |
| name | character | Venue name. |
| capacity | integer | Stadium capacity. |
| grass | logical | TRUE/FALSE response on whether the field is grass or not. |
| city | character | Venue city. |
| state | character | Venue state. |
| zip | character | Venue zip code. |
| country_code | character | Venue country code. |
| latitude | numeric | Venue latitude in decimal degrees. |
| longitude | numeric | Venue longitude in decimal degrees. |
| elevation | character | Venue elevation above sea level. |
| year_constructed | integer | Year in which the venue was constructed. |
| dome | logical | TRUE/FALSE response to whether the venue has a dome or not. |
| timezone | character | Time zone in which the venue resides (i.e. Eastern Time -> "America/New_York"). |
try(cfbd_venues())
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.