View source: R/load_cfb_datasets.R
| load_cfb_rosters_crosswalk | R Documentation |
Loads the roster-level id crosswalk linking CFBD athlete ids to ESPN
athlete ids across seasons. Single cumulative file (not season-
partitioned). Published to the cfb_crosswalk release tag on the
sportsdataverse-data repo.
load_cfb_rosters_crosswalk(..., dbConnection = NULL, tablename = NULL)
... |
Additional arguments passed to an underlying function that writes the season data into a database. |
dbConnection |
A |
tablename |
The name of the data table within the database |
Returns a cfbfastR_data tibble.
| col_name | types | description |
| espn_team_id | integer | |
| fox_team_id | character | |
| person_key | character | |
| espn_athlete_id | integer | |
| fox_athlete_id | character | |
| yahoo_athlete_id | character | |
| name | character | |
| espn_jersey | character | |
| fox_jersey | character | |
| espn_position | character | |
| fox_position | character | |
| yahoo_position | character | |
| match_method | character | |
| matched_sources | character | |
Saiem Gilani
try(load_cfb_rosters_crosswalk())
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.