View source: R/load_espn_cfb.R
| load_espn_cfb_linescores | R Documentation |
Loads season-level period linescores – one row per team-period with
points scored. Published to the
espn_cfb_linescores release tag on the sportsdataverse-data repo.
load_espn_cfb_linescores(
seasons = most_recent_cfb_season(),
...,
dbConnection = NULL,
tablename = NULL
)
seasons |
A vector of 4-digit years associated with given college football seasons. Published coverage runs 2004 through the most recent season. Pass |
... |
Additional arguments passed to an underlying function that writes the season data into a database. |
dbConnection |
A |
tablename |
The name of the data table within the database |
Returns a cfbfastR_data tibble.
| col_name | types | description |
| team_id | integer | |
| period | integer | |
| value | character | |
| game_id | integer | |
| season | integer | |
Saiem Gilani
try(load_espn_cfb_linescores(2004))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.