View source: R/load_ncaa_mfb.R
| load_ncaa_mfb_linescore | R Documentation |
Loads season-level NCAA men's football period linescores parsed from
stats.ncaa.org; one row per team-period. Published to the
ncaa_mfb_linescore release tag on the sportsdataverse-data repo.
load_ncaa_mfb_linescore(
seasons = most_recent_cfb_season(),
...,
dbConnection = NULL,
tablename = NULL
)
seasons |
A vector of 4-digit years associated with given college football seasons. Published coverage runs 2013 through the most recent season. Pass |
... |
Additional arguments passed to an underlying function that writes the season data into a database. |
dbConnection |
A |
tablename |
The name of the data table within the database |
Returns a cfbfastR_data tibble.
| col_name | types | description |
| contest_id | character | |
| team | character | |
| home_away | character | |
| period | character | |
| points | integer | |
| final | integer | |
| game_date | character | |
| venue | character | |
| attendance | integer | |
| espn_game_id | character | |
| season | integer | |
Saiem Gilani
try(load_ncaa_mfb_linescore(2013))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.