View source: R/load_ncaa_mfb.R
| load_ncaa_mfb_player_stats | R Documentation |
Loads season-level NCAA men's football player box statistics parsed from
stats.ncaa.org; one row per player-game-category. Published to the
ncaa_mfb_player_stats release tag on the sportsdataverse-data repo.
load_ncaa_mfb_player_stats(
seasons = most_recent_cfb_season(),
...,
dbConnection = NULL,
tablename = NULL
)
seasons |
A vector of 4-digit years associated with given college football seasons. Published coverage runs 2013 through the most recent season. Pass |
... |
Additional arguments passed to an underlying function that writes the season data into a database. |
dbConnection |
A |
tablename |
The name of the data table within the database |
Returns a cfbfastR_data tibble.
| col_name | types | description |
| contest_id | character | |
| team_id | character | |
| number | character | |
| name | character | |
| position | character | |
| rush_attempts | character | |
| rush_yds_gained | character | |
| rush_yds_lost | character | |
| yds_rush | character | |
| rush_tds | character | |
| rush_long | character | |
| category | character | |
| espn_game_id | character | |
| pass_attempts | character | |
| completions | character | |
| pass_yards | character | |
| interceptions | character | |
| pass_tds | character | |
| pass_eff | character | |
| yds_per_completion | character | |
| pct | character | |
| long_pass | character | |
| rec | character | |
| receiving_yards | character | |
| yards_per_reception | character | |
| rec_td | character | |
| long_rec | character | |
| yds | character | |
| plays | character | |
| pbu | character | |
| int | character | |
| intyds | character | |
| int_ret_tds | character | |
| pdef | character | |
| ko_ret | character | |
| ko_ret_yds | character | |
| kick_ret_tds | character | |
| long_kor | character | |
| sacks | character | |
| solo_tack | character | |
| asst_tack | character | |
| tackles | character | |
| fgm | character | |
| fga | character | |
| fg_blocks_allowed | character | |
| punt_ret | character | |
| punt_ret_yds | character | |
| punt_ret_tds | character | |
| long_pr | character | |
| season | integer | |
Saiem Gilani
try(load_ncaa_mfb_player_stats(2013))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.