View source: R/load_ncaa_mfb.R
| load_ncaa_mfb_rosters | R Documentation |
Loads season-level NCAA men's football rosters from stats.ncaa.org; one
row per player-team-season. Published to the ncaa_mfb_rosters release
tag on the sportsdataverse-data repo.
load_ncaa_mfb_rosters(
seasons = most_recent_cfb_season(),
...,
dbConnection = NULL,
tablename = NULL
)
seasons |
A vector of 4-digit years associated with given college football seasons. Published coverage runs 2013 through the most recent season. Pass |
... |
Additional arguments passed to an underlying function that writes the season data into a database. |
dbConnection |
A |
tablename |
The name of the data table within the database |
Returns a cfbfastR_data tibble.
| col_name | types | description |
| team_id | character | |
| team_name | character | |
| player_id | character | |
| player_name | character | |
| jersey | character | |
| statcrew_jersey | character | |
| player_class | character | |
| position | character | |
| height | character | |
| weight | integer | |
| hometown | character | |
| high_school | character | |
| games_played | integer | |
| games_started | integer | |
| academic_year | integer | |
| season | integer | |
Saiem Gilani
try(load_ncaa_mfb_rosters(2013))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.